#ifndef KJEWEL_H
#define KJEWEL_H

#include <playfield.h>
#include <kmainwindow.h>
#include <kmenubar.h>
#include <klocale.h>
#include <kapp.h>

#define VERSION "0.91"
#define DATE "19.05.2002"
class KJewelMainWindow: public KMainWindow{
  Q_OBJECT

  public:
  /**
   * The constructor method for class KJewelMainWidget
   */
  KJewelMainWindow(const char *name, KApplication *a);
  /**
   * The destructor method for class KJewelMainWidget
   */
  virtual ~KJewelMainWindow();
  void closeEvent(QCloseEvent *);

  Playfield *playfield;

  protected:
    void keyPressEvent(QKeyEvent *e);
    protected slots:
      static const char *about();
	/**
	 * Save the current configuration and quit
	 */
	void quitapp() ;
  private:
    void helpmenu();
    void createMenu();
    KMenuBar *menu;
    QPopupMenu *file, *options, *help;
    KApplication *app;
};
#endif
